# AutoTradingSystem

This project is an automatic trading system based on a Transformer and Reinforcement Learning hybrid model. It is built using HuggingFace's Transformers library and ChatGPT-4.

## Setup

1. Install the required packages: `pip install -r requirements.txt`
2. Run the main script: `python src/main.py`

## Structure

my_project/<br />
│<br />
├── data/<br />
│ ├── raw/ # Raw data goes here<br />
│ └── processed/ # Processed data goes here<br />
│<br />
├── notebooks/ # Jupyter notebooks for exploratory analysis and prototyping<br />
│ ├── data_exploration.ipynb # Notebook for exploring the data<br />
│ ├── data_preprocessing.ipynb # Notebook for preprocessing the data<br />
│ ├── model_prototyping.ipynb # Notebook for prototyping models<br />
│ ├── model_training.ipynb # Notebook for training models<br />
│ ├── model_evaluation.ipynb # Notebook for evaluating models<br />
│ └── hyperparameter_tuning.ipynb # Notebook for tuning hyperparameters<br />
│<br />
├── src/<br />
│ ├── agents/ # Agents module for HuggingFace's Transformers<br />
│ │ ├── init.py<br />
│ │ └── agent_example.py # An example of a Transformer Agent<br />
│ │<br />
│ ├── data/ # Data handling module<br />
│ │ ├── init.py<br />
│ │ ├── data_collection.py # Data collection scripts<br />
│ │ └── data_preprocessing.py # Data preprocessing scripts<br />
│ │<br />
│ ├── models/ # Models module<br />
│ │ ├── init.py<br />
│ │ ├── transformer_model.py # Transformer model script<br />
│ │ ├── rl_model.py # RL model script<br />
│ │ └── trading_model.py # Trading model script<br />
│ │<br />
│ ├── training/ # Training module<br />
│ │ ├── init.py<br />
│ │ └── train.py # Training scripts<br />
│ │<br />
│ ├── evaluation/ # Evaluation module<br />
│ │ ├── init.py<br />
│ │ └── evaluate.py # Evaluation scripts<br />
│ │<br />
│ ├── utils/ # Utility module<br />
│ │ ├── init.py<br />
│ │ ├── utils.py # Utility scripts (including seeding function)<br />
│ │ └── metrics.py # Metrics computation scripts<br />
│ │<br />
│ └── main.py # Main script to run the model<br />
│<br />
├── config/ # Configuration files<br />
│ ├── transformer.json<br />
│ ├── rl.json<br />
│ └── training.json<br />
│<br />
├── tests/ # Test module<br />
│ ├── init.py<br />
│ ├── test_data.py # Tests for data collection and preprocessing<br />
│ ├── test_models.py # Tests for model creation<br />
│ ├── test_training.py # Tests for model training<br />
│ ├── test_evaluation.py # Tests for model evaluation<br />
│ └── test_utils.py # Tests for utility functions<br />
│<br />
├── .gitignore # Specifies which files should be ignored by Git<br />
├── README.md # Project description and instructions<br />
└── requirements.txt # List of Python dependencies<br />
