import requests
import json
import os
import pandas as pd
from pandas_datareader import data as pdr
from datetime import datetime, timedelta
import yfinance as yf

yf.pdr_override()  # Override pandas_datareader's get_data_yahoo() method

class DataCollector:
    def __init__(self, tickers, start_date, end_date):
        self.tickers = tickers
        self.start_date = start_date
        self.end_date = end_date

    def fetch_data_from_yahoo(self):
        data = pdr.get_data_yahoo(self.tickers, start=self.start_date, end=self.end_date)
        return data

    def fetch_data_from_binance(self, symbol, interval='1d', limit=500):
        url = f'https://api.binance.com/api/v3/klines?symbol={symbol}&interval={interval}&limit={limit}'
        response = requests.get(url)
        response.raise_for_status()
        data = response.json()
        return data

    def save_data(self, data, filename):
        if isinstance(data, pd.DataFrame):
            data.to_csv(filename)
        else:
            with open(filename, 'w') as f:
                json.dump(data, f)

if __name__ == "__main__":
    tickers = ['AAPL', 'GOOGL', 'TSLA']
    data_collector = DataCollector(tickers, '2020-01-01', '2021-12-31')

    # Fetch and save stock data from Yahoo Finance
    stock_data = data_collector.fetch_data_from_yahoo()
    data_collector.save_data(stock_data, 'stock_data.csv')

    # Fetch and save cryptocurrency data from Binance
    crypto_data = data_collector.fetch_data_from_binance('BTCUSDT')
    data_collector.save_data(crypto_data, 'crypto_data.json')
