import pandas as pd
from sklearn.preprocessing import MinMaxScaler

class DataPreprocessor:
    def __init__(self, filename, file_format='csv'):
        if file_format == 'csv':
            self.data = pd.read_csv(filename)
        elif file_format == 'json':
            self.data = pd.read_json(filename)
        else:
            raise ValueError(f"Unsupported file format: {file_format}")

    def drop_nulls(self):
        self.data.dropna(inplace=True)

    def scale_data(self, columns):
        scaler = MinMaxScaler()
        self.data[columns] = scaler.fit_transform(self.data[columns])

    def preprocess_data(self):
        # Call preprocessing steps
        self.drop_nulls()

        # Assume that we want to scale all numerical columns
        numerical_cols = self.data.select_dtypes(include=['float64', 'int']).columns.tolist()
        self.scale_data(numerical_cols)

    def save_data(self, filename, file_format='csv'):
        if file_format == 'csv':
            self.data.to_csv(filename, index=False)
        elif file_format == 'json':
            self.data.to_json(filename)
        else:
            raise ValueError(f"Unsupported file format: {file_format}")

if __name__ == "__main__":
    data_preprocessor = DataPreprocessor('stock_data.csv')
    data_preprocessor.preprocess_data()
    data_preprocessor.save_data('processed_data.csv')
