class TradingModel:
    def __init__(self, transformer_model, rl_model):
        """
        Initializes the TradingAgent with the Transformer and RL models.

        Parameters:
        transformer_model (TransformerModel): The Transformer model to use for predictions.
        rl_model (RLModel): The RL model to use for predictions.
        """
        self.transformer_model = transformer_model
        self.rl_model = rl_model

    def make_decision(self, stock_prices, obs):
        """
        Makes a trading decision based on the given stock prices and observations.

        Parameters:
        stock_prices (np.array): The stock price sequence to feed to the Transformer model.
        obs (np.array): The observations to feed to the RL model.

        Returns:
        int: The action chosen by the agent (0: hold, 1: buy, 2: sell).
        """
        # Get embeddings from transformer model
        embeddings = self.transformer_model.get_embeddings(stock_prices)
        
        # Compute a single vector representation of the embeddings
        vector_representation = embeddings.mean(dim=0)

        # Combine vector representation with observations
        combined_input = np.concatenate((vector_representation.detach().numpy(), obs))

        # Get action from RL model
        action = self.rl_model.predict(combined_input)

        return action
