import torch
from torch.utils.data import DataLoader
from src.models.transformer_model import TransformerModel
from src.models.rl_model import RLModel
from src.data.data_preprocessing import Dataset

def train_transformer_model(transformer_model, train_data, epochs, learning_rate):
    """
    Train the Transformer model.

    Parameters:
    transformer_model (TransformerModel): The transformer model to train.
    train_data (Dataset): The training data.
    epochs (int): The number of epochs to train for.
    learning_rate (float): The learning rate for the optimizer.
    """
    # Create data loader
    dataloader = DataLoader(train_data, batch_size=32, shuffle=True)
    
    # Set device
    device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
    transformer_model.to(device)

    # Define loss function and optimizer
    criterion = torch.nn.MSELoss()  # Change to mean squared error loss for regression
    optimizer = torch.optim.AdamW(transformer_model.parameters(), lr=learning_rate)  # Use AdamW optimizer

    # Training loop
    for epoch in range(epochs):
        for i, (inputs, targets) in enumerate(dataloader):
            inputs, targets = inputs.to(device), targets.to(device)

            # Forward pass
            outputs = transformer_model(inputs)
            
            # Compute loss
            loss = criterion(outputs, targets)

            # Backward pass and optimization
            optimizer.zero_grad()
            loss.backward()
            optimizer.step()

            # Print loss every 100 batches
            if i % 100 == 0:
                print(f'Epoch [{epoch+1}/{epochs}], Step [{i+1}/{len(dataloader)}], Loss: {loss.item()}')

def train_rl_model(rl_model, env, timesteps):
    """
    Train the RL model.

    Parameters:
    rl_model (RLModel): The RL model to train.
    env (gym.Env): The Gym environment to use for training.
    timesteps (int): The number of timesteps to train for.
    """
    rl_model.train(timesteps)
