from sklearn.metrics import accuracy_score, precision_score, recall_score, f1_score, confusion_matrix
import numpy as np

def compute_classification_metrics(y_true, y_pred):
    """
    Compute classification metrics.

    Parameters:
    y_true (np.array): Ground truth labels.
    y_pred (np.array): Predicted labels.

    Returns:
    dict: A dictionary containing the computed metrics.
    """
    accuracy = accuracy_score(y_true, y_pred)
    precision = precision_score(y_true, y_pred, average='weighted', zero_division=0)
    recall = recall_score(y_true, y_pred, average='weighted', zero_division=0)
    f1 = f1_score(y_true, y_pred, average='weighted', zero_division=0)
    conf_matrix = confusion_matrix(y_true, y_pred)

    return {'accuracy': accuracy, 'precision': precision, 'recall': recall, 'f1': f1, 'confusion_matrix': conf_matrix}

def compute_reward_metrics(total_rewards, num_episodes):
    """
    Compute reward metrics.

    Parameters:
    total_rewards (list): List of total rewards per episode.
    num_episodes (int): Total number of episodes.

    Returns:
    dict: A dictionary containing the computed metrics.
    """
    average_reward = sum(total_rewards) / num_episodes
    max_reward = max(total_rewards)
    min_reward = min(total_rewards)
    std_dev_reward = np.std(total_rewards)

    return {'average_reward': average_reward, 'max_reward': max_reward, 'min_reward': min_reward, 'std_dev_reward': std_dev_reward}
